@@ -56,12 +56,12 @@ plotevol<-function (DEVOL, log = 0, fl = 0, fh = 10, col = col, ylog = FALSE,
     if (ylog == TRUE) {
         Yplmin = min(log10(y[yflag]))
         Yplmax = max(log10(y[yflag]))
-        why = RESCALE(log10(y[yflag]), 0, perc, Yplmin, Yplmax)
+        why = RPMG::RESCALE(log10(y[yflag]), 0, perc, Yplmin, Yplmax)
     }
     else {
         Yplmin = min(y[yflag], na.rm = TRUE)
         Yplmax = max(y[yflag], na.rm = TRUE)
-        why = RESCALE((y[yflag]), 0, perc, Yplmin, Yplmax)
+        why = RPMG::RESCALE((y[yflag]), 0, perc, Yplmin, Yplmax)
     }
     subI = IMAT[, yflag]
     if (log <= 0) {
@@ -89,7 +89,7 @@ plotevol<-function (DEVOL, log = 0, fl = 0, fh = 10, col = col, ylog = FALSE,
         ylab = "")
     image(x, why, ImPlot, add = TRUE, col = col, xlab = "time",
         ylab = "freq", axes = FALSE)
-    trace = RESCALE(a, perc, 1, min(a, na.rm = TRUE), max(a,
+    trace = RPMG::RESCALE(a, perc, 1, min(a, na.rm = TRUE), max(a,
         na.rm = TRUE))
     lines(tim, trace)
     Tdiff = max(tim, na.rm = TRUE) - min(tim, na.rm = TRUE)
@@ -108,7 +108,7 @@ plotevol<-function (DEVOL, log = 0, fl = 0, fh = 10, col = col, ylog = FALSE,
     if (ylog == TRUE) {
         axspec = pretty(log10(y[yflag]), n = 10)
         axspec = axspec[axspec <= max(log10(y[yflag]))]
-        raxspec = RESCALE(axspec, 0, perc, min(log10(y[yflag]),
+        raxspec = RPMG::RESCALE(axspec, 0, perc, min(log10(y[yflag]),
             na.rm = TRUE), max(log10(y[yflag]), na.rm = TRUE))
         axspec = 10^(axspec[axspec <= max(log10(y[yflag]))])
         axspec[axspec < 1] = 1/axspec[axspec < 1]
@@ -116,7 +116,7 @@ plotevol<-function (DEVOL, log = 0, fl = 0, fh = 10, col = col, ylog = FALSE,
     else {
         axspec = pretty(y[yflag], n = 10)
         axspec = axspec[axspec <= max(y[yflag], na.rm = TRUE)]
-        raxspec = RESCALE(axspec, 0, perc, min(y[yflag], na.rm = TRUE),
+        raxspec = RPMG::RESCALE(axspec, 0, perc, min(y[yflag], na.rm = TRUE),
             max(y[yflag], na.rm = TRUE))
     }
     axis(2, at = raxspec, labels = format.default(axspec, digits = 3),
@@ -137,7 +137,7 @@ plotevol<-function (DEVOL, log = 0, fl = 0, fh = 10, col = col, ylog = FALSE,
     }
     axtrace = range(a, na.rm = TRUE)
     if (axtrace[1] < axtrace[2]) {
-        raxtrace = RESCALE(axtrace, perc, 1, axtrace[1], axtrace[2])
+        raxtrace = RPMG::RESCALE(axtrace, perc, 1, axtrace[1], axtrace[2])
         axis(4, at = raxtrace, labels = format.default(axtrace,
             digits = 3), pos = max(tim, na.rm = TRUE))
         if (!is.null(WUNITS)) {
@@ -150,7 +150,7 @@ plotevol<-function (DEVOL, log = 0, fl = 0, fh = 10, col = col, ylog = FALSE,
         print("plotevol error in input amplitudes")
     }
     if (CSCALE == TRUE) {
-        HOZscale(ImPlot, col, units = units, s1 = 0.4, s2 = 0.95)
+        RPMG::HOZscale(ImPlot, col, units = units, s1 = 0.4, s2 = 0.95)
     }
     invisible(list(y = y[yflag], why = why, yBounds = c(0, perc,
         Yplmin, Yplmax), x = x, yat = raxspec))
